# quala

Quala implements different accelerators for optimization
solvers, root finders and fixed-point methods, such as Broyden-type quasi-Newton
methods and Anderson acceleration.

The algorithms are implemented in C++, and are available through a Python 
interface.

## Installation

The Python interface can be installed from PyPI using `pip`:
```sh
python3 -m pip install quala
```

Installation instructions for the C++ library can be found in the 
[documentation](https://tttapa.github.io/quala/Doxygen/installation.html).

## Examples and documentation

- [Python Documentation (Sphinx)](https://tttapa.github.io/quala/Sphinx/)
- [C++ Documentation (Doxygen)](https://tttapa.github.io/quala/Doxygen/)
- [Python Examples (Sphinx)](https://tttapa.github.io/quala/Sphinx/examples/)
- [C++ Examples (Doxygen)](https://tttapa.github.io/quala/Doxygen/examples.html)
